==> apache-camel-4.17.0-src.zip: apache-camel-4.17.0/test-infra/camel-test-infra-ollama/src/main/java/org/apache/camel/test/infra/ollama/commons/OllamaProperties.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.test.infra.ollama.commons;

public class OllamaProperties {

    public static final String CONTAINER = "ollama.container";
    public static final String MODEL = "ollama.model";
    public static final String API_KEY = "ollama.api.key";

    public static final String ENDPOINT = "ollama.endpoint";

    /**
     * URL for connecting to a local Ollama instance running on the host. Default: http://localhost:11434
     * <p>
     * This property is used when auto-detecting local Ollama availability. If a local Ollama instance is found at this
     * URL, it will be used instead of starting a Docker container.
     * </p>
     */
    public static final String OLLAMA_HOST_URL = "ollama.host.url";

    public static final String CPU_COUNT = "ollama.container.cpu.count";
    public static final String MEMORY_LIMIT = "ollama.container.memory.limit";
    public static final String ENABLE_GPU = "ollama.container.enable.gpu";

    private OllamaProperties() {

    }
}

==> apache-camel-4.18.0-src.zip: apache-camel-4.18.0/test-infra/camel-test-infra-ollama/src/main/java/org/apache/camel/test/infra/ollama/commons/OllamaProperties.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.test.infra.ollama.commons;

public class OllamaProperties {

    public static final String CONTAINER = "ollama.container";
    public static final String MODEL = "ollama.model";
    public static final String EMBEDDING_MODEL = "ollama.embedding.model";
    public static final String API_KEY = "ollama.api.key";

    public static final String ENDPOINT = "ollama.endpoint";

    /**
     * URL for connecting to a local Ollama instance running on the host. Default: http://localhost:11434
     * <p>
     * This property is used when auto-detecting local Ollama availability. If a local Ollama instance is found at this
     * URL, it will be used instead of starting a Docker container.
     * </p>
     */
    public static final String OLLAMA_HOST_URL = "ollama.host.url";

    public static final String CPU_COUNT = "ollama.container.cpu.count";
    public static final String MEMORY_LIMIT = "ollama.container.memory.limit";
    public static final String ENABLE_GPU = "ollama.container.enable.gpu";

    // OpenAI-specific properties (used when ollama.instance.type=openai)
    public static final String OPENAI_API_KEY = "openai.api.key";
    public static final String OPENAI_ENDPOINT = "openai.endpoint";
    public static final String OPENAI_MODEL = "openai.model";
    public static final String OPENAI_EMBEDDING_MODEL = "openai.embedding.model";

    private OllamaProperties() {

    }
}
